## 1.1.0 (2025-06-04)

### Feat

- **bot**: support sending files as action result (#78)

## 1.0.0 (2025-05-27)

### Feat

- **cli**: added first commands (#51)

## 0.8.0 (2025-05-20)

### Feat

- **bot**: user can now be requested in action function parameters (#48)

## 0.7.1 (2025-05-18)

### Fix

- **tg**: auth handler now calls check update of wrapped handler (#44)

## 0.7.0 (2025-05-13)

### Feat

- **users**: initial user functionality (#39)

## 0.6.0 (2025-05-05)

### Feat

- **web**: initial implementation (#36)

## 0.5.3 (2025-05-02)

### Fix

- **tg**: markdown escaping (#34)

## 0.5.2 (2025-05-01)

### Fix

- checking out latest ref instead of action ref

## 0.5.1 (2025-05-01)

### Fix

- added metadata to pyproject.toml

## 0.5.0 (2025-05-01)

### Feat

- **bot**: added (#27)

## 0.4.0 (2025-04-17)

### Feat

- **tg**: added (#19)

## 0.3.0 (2025-04-01)

### Feat

- **templates**: added (#14)

## 0.2.0 (2025-03-28)

### Feat

- **base**: added (#5)

## 0.1.1 (2025-03-19)

### Refactor

- using new file header

## 0.1.0 (2025-03-18)

### Feat

- added pre-commit and ruff
- initial project setup

### Fix

- delete boilerplate code
